@@ -197,13 +197,13 @@ void MainWindow::writeSettings()
         sett.setValue("icons", "0");
     }
 
-    QString Transitions;
-    if ( ui->transitions->checkState() == Qt::Checked ) {
-        themesett.setValue("transitions", "1");
-    }
-    else {
-        themesett.setValue("transitions", "0");
-    }
+//    QString Transitions;
+  //  if ( ui->transitions->checkState() == Qt::Checked ) {
+    //    themesett.setValue("transitions", "1");
+    // }
+//    else {
+//        themesett.setValue("transitions", "0");
+//    }
 }
 
 void MainWindow::readSettings()
@@ -211,7 +211,7 @@ void MainWindow::readSettings()
     QSettings sett("ThemeCustomizer", "Boxes");
     QSettings themesett("ThemeCustomizer", currenttheme);
     int icons = sett.value("icons").toInt();
-    int transitions = themesett.value("transitions").toInt();
+//    int transitions = themesett.value("transitions").toInt();
     int snap = sett.value("snap").toInt();
     int fontsize = themesett.value("fontsize").toInt();
     QString fontsizestring = themesett.value("fontsize").toString();
@@ -234,7 +234,7 @@ void MainWindow::readSettings()
         ui->Icons->setCheckState(Qt::Unchecked);
     }
 
-    if ( transitions == 1 ) {
+    if ( QFile::exists("/etc/hildon/theme/transitionsbycustomizer") && QFile::exists("/etc/hildon/theme/transitions.ini") ) {
         ui->transitions->setCheckState(Qt::Checked);
     } else {
         ui->transitions->setCheckState(Qt::Unchecked);
@@ -837,7 +837,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: d-iivil - Licence: Freeware & open source (GPL)");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-62<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-63<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
