@@ -11,6 +11,14 @@
         <source>Current theme: </source>
         <translation>当前主题:</translation>
     </message>
+    <message>
+        <source>Theme customizations applied!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Restart the device to reload all theme elements and make all changes visible.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Use custom (fast) window transitions</source>
         <translation type="unfinished"></translation>
