@@ -8,6 +8,14 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Theme customizations applied!</source>
+        <translation>Teeman kustomoinnit asetettu!</translation>
+    </message>
+    <message>
+        <source>Restart the device to reload all theme elements and make all changes visible.</source>
+        <translation>Käynnistä laite uudelleen tehdäksesi kaikki muutokset näkyviksi.</translation>
+    </message>
     <message>
         <source>Tap to change</source>
         <translation>Klikkaa vaihtaaksesi</translation>
